// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package convert

import "github.com/cespare/xxhash/v2"

// Hash computes the 64-bit Hash digest of key.
func Hash(key []byte) uint64 {
	return xxhash.Sum64(key)
}

// HashStr computes the 64-bit Hash digest of key.
func HashStr(key string) uint64 {
	return xxhash.Sum64String(key)
}
